@@ -11,7 +11,7 @@ from typing import TypeAlias
 if sys.version_info >= (3, 11):
     from importlib.resources.abc import Traversable
 else:
-    from importlib.abc import Traversable  # pylint: disable=deprecated-class
+    from importlib.abc import Traversable
 
 
 __all__ = ["Traversable", "TypeAlias", "importlib_metadata"]
